@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import print_function
 import pyaudio
 import wave
 import numpy as np
@@ -8,6 +9,12 @@ import time
 import os
 import sys
 from contextlib import contextmanager
+
+import argparse
+parser=argparse.ArgumentParser(description='Record and playback audio via Respeaker ')
+args=parser.parse_args()
+
+
 import stretch_body.hello_utils as hu
 hu.print_stretch_re_use()
 
@@ -122,7 +129,8 @@ class Tuning:
             usb.util.CTRL_IN | usb.util.CTRL_TYPE_VENDOR | usb.util.CTRL_RECIPIENT_DEVICE,
             0, cmd, id, length, self.TIMEOUT)
 
-        response = struct.unpack(b'ii', response.tostring())
+        #response = struct.unpack(b'ii', response.tostring())
+        response = struct.unpack(b'ii', response.tobytes())
 
         if data[2] == 'int':
             result = response[0]
@@ -187,8 +195,10 @@ def record_audio(seconds=3):
     frames = []
     for i in range(0, int(RESPEAKER_RATE / CHUNK * seconds)):
         data = stream.read(CHUNK)
-        a = np.fromstring(data,dtype=np.int16)[0::6] # extracts fused channel 0
-        frames.append(a.tostring())
+        #a = np.fromstring(data,dtype=np.int16)[0::6] # extracts fused channel 0
+        #frames.append(a.tostring())
+        a = np.frombuffer(data, dtype=np.int16)[0::6]  # extracts fused channel 0
+        frames.append(a.tobytes())
 
     stream.stop_stream()
     stream.close()
@@ -233,17 +243,17 @@ if __name__ == "__main__":
             while True:
                 try:
                     if not printed_wait_statement and respeaker.is_voice() == 0:
-                        print "\n* waiting for audio..."
+                        print("\n* waiting for audio...")
                         printed_wait_statement = True
                     else:
                         if respeaker.is_voice() == 1:
-                            print "* recording 3 seconds"
+                            print("* recording 3 seconds")
                             frames = record_audio()
-                            print "* done"
+                            print("* done")
                             time.sleep(1)
-                            print "* playing audio"
+                            print("* playing audio")
                             play_audio(frames)
-                            print "* done"
+                            print("* done")
                             time.sleep(1)
                             printed_wait_statement = False
                         time.sleep(0.01)
